ccache: A compiler cache
========================

Description
-----------

ccache is a compiler cache. It speeds up recompilation by caching
previous compilations and detecting when the same compilation is being
done again. Supported languages are C, C++, Objective-C and
Objective-C++.

License
-------

GNU General Public License version 3 or later


Upstream Contact
----------------

-  Author: Andrew Tridgell
-  Website: http://ccache.samba.org/
